%%
%% This is file `thesis-ekcu.cls',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% thesis-ekf.dtx  (with options: `ekcu')
%% This is a generated file.
%% Copyright (C) 2014-2026 by Tibor Tómács
%% This file may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.2 of this license or (at your option) any later
%% version. The latest version of this license is in:
%% 
%% http://www.latex-project.org/lppl.txt
%% 
%% and version 1.2 or later is part of all distributions of
%% LaTeX version 1999/12/01 or later.
%% 

\NeedsTeXFormat{LaTeX2e}[2020/10/01]
\ProvidesClass{thesis-ekcu}[2026/01/10 v5.0 Thesis class for Eszterházy Károly Catholic University (Eger, Hungary)]

\typeout{Class 'thesis-ekcu' is an alias for 'thesis-ekf' and will simply load 'thesis-ekf'.}

\def\thesisekcu@setalias{
  \let\thesisekcu@orig@setkeys\setkeys
  \def\setkeys##1##2{%
    \def\thesisekcu@tmp{##1}%
    \def\thesisekcu@fam{thesis-ekcu}%
    \ifx\thesisekcu@tmp\thesisekcu@fam
      \thesisekcu@orig@setkeys{thesis-ekf}{##2}%
    \else
      \thesisekcu@orig@setkeys{##1}{##2}%
    \fi
  }
}

\LoadClassWithOptions{thesis-ekf}

\endinput
%%
%% End of file `thesis-ekcu.cls'.
