%%
%% This is file `mynsfc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% mynsfc.dtx  (with options: `definitions')
%% 
%% This is a generated file.
%% 
%% Copyright (C) 2015-2026 by Fei Qi <fred.qi@gmail.com>
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. The latest version of this license is in:
%% 
%%    http://www.latex-project.org/lppl.txt
%% 
%% and version 1.3c or later is part of all distributions of
%% LaTeX version 2008/05/04 or later.
%% 
%% This work consists of the file mynsfc.dtx and the derived files
%% mynsfc.cls, mynsfc.def, and the example files.
%% 
%% ----------------------------------------------------------------
%% mynsfc --- A CTeX-based template for writing the main text of NSFC
%%     proposals, aligned with the 2026 General Program specification.
%% Author: Fei Qi <fred.qi@gmail.com>
%% ----------------------------------------------------------------
%% 
\ProvidesFile{mynsfc.def}[2026/01/25 2.00 NSFC definitions]
\makeatletter
%% Customizable strings for mynsfc class
\providecommand{\mynsfc@title}{报告正文（2026版）}
\providecommand{\mynsfc@subtitle}{参照以下提纲撰写，要求内容翔实、清晰，层次分明，标题突出。\textbf{\color{red}申请书正文原则上不超过30页，鼓励简洁表达。}\cemph{请勿删除或改动下述提纲标题及括号中的文字。}}
\providecommand{\mynsfcrefname}{参考文献}
\providecommand{\mynsfccvname}{相关工作}
\providecommand{\mynsfcpatentcn}{中国发明专利}
%% Part I
\providecommand{\mynsfc@part@I@title}{立项依据}
\providecommand{\mynsfc@part@I@subtitle}{为什么要开展此项研究，研究的科学技术价值如何}
%% Part II
\providecommand{\mynsfc@part@II@title}{研究内容}
\providecommand{\mynsfc@part@II@subtitle}{提纲不做限制，请按照研究工作的自身逻辑撰写。应提炼出特色与创新点、年度研究计划}
%% Part III
\providecommand{\mynsfc@part@III@title}{研究基础}
\providecommand{\mynsfc@part@III@subtitle}{}
%% Section III-I ...
\providecommand{\mynsfc@section@III@I@title}{研究基础与可行性分析\textmd{（与本项目相关的研究工作积累和已取得的研究工作成绩，研究风险的应对措施等）；}}
\providecommand{\mynsfc@section@III@II@title}{工作条件\textmd{（包括已具备的实验条件，尚缺少的实验条件和拟解决的途径，包括利用国家实验室、全国重点实验室和部门重点实验室等研究基地的计划与落实情况）；}}
\providecommand{\mynsfc@section@III@III@title}{正在承担的与本项目相关的科研项目情况\textmd{（申请人和主要参与者正在承担的与本项目相关的科研项目情况，包括国家自然科学基金的项目和国家其他科技计划项目，要注明项目的资助机构、项目类别、批准号、项目名称、获资助金额、起止年月、与本项目的关系及负责的内容等）；}}
\providecommand{\mynsfc@section@III@IV@title}{完成国家自然科学基金项目情况\textmd{（对申请人负责的前一个已资助期满的科学基金项目（项目名称及批准号）完成情况、后续研究进展及与本申请项目的关系加以详细说明。另附该项目的研究工作总结摘要（限500字）和相关成果详细目录）。}}
%% Part IV
\providecommand{\mynsfc@part@IV@title}{其他需要说明的情况}
\providecommand{\mynsfc@part@IV@subtitle}{}
%% Section IV-I ...
\providecommand{\mynsfc@section@IV@I@title}{\textmd{申请人同年申请不同类型的国家自然科学基金项目情况（列明同年申请的其他项目的项目类型、项目名称信息，并说明与本项目之间的区别与联系；已收到自然科学基金委不予受理或不予资助决定的，无需列出）。}}
\providecommand{\mynsfc@section@IV@II@title}{\textmd{具有高级专业技术职务（职称）的申请人或者主要参与者是否存在同年申请或者参与申请国家自然科学基金项目的单位不一致的情况；如存在上述情况，列明所涉及人员的姓名，申请或参与申请的其他项目的项目类型、项目名称、单位名称、上述人员在该项目中是申请人还是参与者，并说明单位不一致原因。}}
\providecommand{\mynsfc@section@IV@III@title}{\textmd{具有高级专业技术职务（职称）的申请人或者主要参与者是否存在与正在承担的国家自然科学基金项目的单位不一致的情况；如存在上述情况，列明所涉及人员的姓名，正在承担项目的批准号、项目类型、项目名称、单位名称、起止年月，并说明单位不一致原因。}}
\providecommand{\mynsfc@section@IV@IV@title}{\textmd{申请人和主要参与者同年以不同专业技术职务（职称）申请或参与申请科学基金项目的情况（应详细说明原因）。}}
\providecommand{\mynsfc@section@IV@V@title}{\textmd{其他。}}
%% 
%%
%% End of file `mynsfc.def'.
